import pylrc
import os

class Lyric:
    def __init__(self, text, start, dur, filename):
        self.text = text
        self.start_s = start
        self.dur_s = dur
        self.lrc_file = filename
        self.wav_file = self.get_wav_filename(filename)

    def get_wav_filename(self, filename):
        wav_file = filename.split('.')[0] + ".wav"
        wav_file = wav_file.replace("/lrc/", "/audio/" )

        return wav_file
    
    def print_lrc(self):
        print(self.text, self.start_s, self.dur_s, self.lrc_file, self.wav_file)

def time_to_sec(t):
    m, s = map(float, t.split(':'))
    return m * 60 + s


def convert_lrc(filename):
    filename = os.path.abspath(filename)
    lrc_file = open(filename)
    lrc_string = ''.join(lrc_file.readlines())
    lrc_file.close()

    subs = pylrc.parse(lrc_string)

    lrc_string = subs.toLRC()

    time_format = "[00:00.00]"
    lines = [line for line in lrc_string.splitlines() if len(line) > len(time_format) and line[1].isnumeric()]
    next_pos = 0

    lyric_timing = []
    for i in range(len(lines) - 1):
        lrc_text = lines[i][10:].strip()
        if ":" not in lrc_text:
            next_pos = time_to_sec(lines[i + 1][1:9])
            lrc_pos = time_to_sec(lines[i][1:9])
            lrc_dur = round(next_pos - lrc_pos, 2)
            if (lrc_text != ""):
                lyric_timing.append(Lyric(lrc_text, lrc_pos, lrc_dur, filename))

    return lyric_timing


def get_lyric_timing(lyric_dir):
    lyric_timings = []
    for file in os.listdir(lyric_dir):
        lyric_timings.extend(convert_lrc(os.path.join(lyric_dir, file)))
    
    return lyric_timings
